@@ -11,7 +11,7 @@ ImageType = Union[np.ndarray, Image.Image]
 
 
 def get_urls_from_response(response):
-    return [x["url"] for x in json.loads(response["body"])["images"]]
+    return [[x["url"], x["distance"]] for x in json.loads(response["body"])["images"]]
 
 
 def get_ternaus_token():
